@@ -115,15 +115,15 @@ typedef struct _SpecialOption {
 } SpecialOption;
 
 const SpecialOption specialOptions[] = {
-    {"run_key", "core", FALSE,
+    {"run_key", "gnomecompat", FALSE,
      METACITY "/global_keybindings/panel_run_dialog", OptionKey},
-    {"main_menu_key", "core", FALSE,
+    {"main_menu_key", "gnomecompat", FALSE,
      METACITY "/global_keybindings/panel_main_menu", OptionKey},
-    {"run_command_screenshot_key", "core", FALSE,
+    {"run_command_screenshot_key", "gnomecompat", FALSE,
      METACITY "/global_keybindings/run_command_screenshot", OptionKey},
-    {"run_command_window_screenshot_key", "core", FALSE,
+    {"run_command_window_screenshot_key", "gnomecompat", FALSE,
      METACITY "/global_keybindings/run_command_window_screenshot", OptionKey},
-    {"run_command_terminal_key", "core", FALSE,
+    {"run_command_terminal_key", "gnomecompat", FALSE,
      METACITY "/global_keybindings/run_command_terminal", OptionKey},
 
     {"toggle_window_maximized_key", "core", FALSE,
@@ -182,54 +182,54 @@ const SpecialOption specialOptions[] = {
     {"toggle_fullscreen_key", "extrawm", FALSE,
      METACITY "/window_keybindings/toggle_fullscreen", OptionKey},
 
-    {"command0", "core", FALSE,
+    {"command0", "commands", FALSE,
      METACITY "/keybinding_commands/command_1", OptionString},
-    {"command1", "core", FALSE,
+    {"command1", "commands", FALSE,
      METACITY "/keybinding_commands/command_2", OptionString},
-    {"command2", "core", FALSE,
+    {"command2", "commands", FALSE,
      METACITY "/keybinding_commands/command_3", OptionString},
-    {"command3", "core", FALSE,
+    {"command3", "commands", FALSE,
      METACITY "/keybinding_commands/command_4", OptionString},
-    {"command4", "core", FALSE,
+    {"command4", "commands", FALSE,
      METACITY "/keybinding_commands/command_5", OptionString},
-    {"command5", "core", FALSE,
+    {"command5", "commands", FALSE,
      METACITY "/keybinding_commands/command_6", OptionString},
-    {"command6", "core", FALSE,
+    {"command6", "commands", FALSE,
      METACITY "/keybinding_commands/command_7", OptionString},
-    {"command7", "core", FALSE,
+    {"command7", "commands", FALSE,
      METACITY "/keybinding_commands/command_8", OptionString},
-    {"command8", "core", FALSE,
+    {"command8", "commands", FALSE,
      METACITY "/keybinding_commands/command_9", OptionString},
-    {"command9", "core", FALSE,
+    {"command9", "commands", FALSE,
      METACITY "/keybinding_commands/command_10", OptionString},
-    {"command10", "core", FALSE,
+    {"command10", "commands", FALSE,
      METACITY "/keybinding_commands/command_11", OptionString},
-    {"command11", "core", FALSE,
+    {"command11", "commands", FALSE,
      METACITY "/keybinding_commands/command_12", OptionString},
 
-    {"run_command0_key", "core", FALSE,
+    {"run_command0_key", "commands", FALSE,
      METACITY "/global_keybindings/run_command_1", OptionKey},
-    {"run_command1_key", "core", FALSE,
+    {"run_command1_key", "commands", FALSE,
      METACITY "/global_keybindings/run_command_2", OptionKey},
-    {"run_command2_key", "core", FALSE,
+    {"run_command2_key", "commands", FALSE,
      METACITY "/global_keybindings/run_command_3", OptionKey},
-    {"run_command3_key", "core", FALSE,
+    {"run_command3_key", "commands", FALSE,
      METACITY "/global_keybindings/run_command_4", OptionKey},
-    {"run_command4_key", "core", FALSE,
+    {"run_command4_key", "commands", FALSE,
      METACITY "/global_keybindings/run_command_5", OptionKey},
-    {"run_command5_key", "core", FALSE,
+    {"run_command5_key", "commands", FALSE,
      METACITY "/global_keybindings/run_command_6", OptionKey},
-    {"run_command6_key", "core", FALSE,
+    {"run_command6_key", "commands", FALSE,
      METACITY "/global_keybindings/run_command_7", OptionKey},
-    {"run_command7_key", "core", FALSE,
+    {"run_command7_key", "commands", FALSE,
      METACITY "/global_keybindings/run_command_8", OptionKey},
-    {"run_command8_key", "core", FALSE,
+    {"run_command8_key", "commands", FALSE,
      METACITY "/global_keybindings/run_command_9", OptionKey},
-    {"run_command9_key", "core", FALSE,
+    {"run_command9_key", "commands", FALSE,
      METACITY "/global_keybindings/run_command_10", OptionKey},
-    {"run_command10_key", "core", FALSE,
+    {"run_command10_key", "commands", FALSE,
      METACITY "/global_keybindings/run_command_11", OptionKey},
-    {"run_command11_key", "core", FALSE,
+    {"run_command11_key", "commands", FALSE,
      METACITY "/global_keybindings/run_command_12", OptionKey},
 
     {"rotate_to_1_key", "rotate", FALSE,
@@ -406,19 +406,35 @@ isIntegratedOption (CCSSetting *setting,
 
     for (i = 0; i < N_SOPTIONS; i++)
     {
-	if ((strcmp (setting->name, specialOptions[i].settingName) == 0) &&
-	    ((!setting->parent->name && !specialOptions[i].pluginName) ||
-	     (setting->parent->name && specialOptions[i].pluginName &&
-	      (strcmp (setting->parent->name,
-		       specialOptions[i].pluginName) == 0))) &&
-	    ((setting->isScreen && specialOptions[i].screen) ||
-	     (!setting->isScreen && !specialOptions[i].screen)))
+	SpecialOption *opt = &specialOptions[i];
+
+	if (strcmp (setting->name, opt->settingName) != 0)
+	    continue;
+
+	if (setting->parent->name)
 	{
-	    if (index)
-		*index = i;
-	    return TRUE;
+	    if (!opt->pluginName)
+		continue;
+	    if (strcmp (setting->parent->name, opt->pluginName) != 0)
+		continue;
 	}
+	else
+	{
+	    if (opt->pluginName)
+		continue;
+	}
+
+	if (setting->isScreen && !opt->screen)
+	    continue;
+	if (!setting->isScreen && opt->screen)
+	    continue;
+
+	if (index)
+	    *index = i;
+
+	return TRUE;
     }
+
     return FALSE;
 }
 
@@ -1394,28 +1410,25 @@ writeListValue (CCSSetting *setting,
 	g_slist_free (valueList);
 }
 
-static void
+static Bool
 setGnomeMouseButtonModifier (unsigned int modMask)
 {
     char   *modifiers, *currentValue;
     GError *err = NULL;
 
     modifiers = ccsModifiersToString (modMask);
-
     if (!modifiers)
-	modifiers = strdup ("");
-    if (!modifiers)
-	return;
+	return FALSE;
 
-    currentValue =
-	gconf_client_get_string(client,
-				METACITY "/general/mouse_button_modifier",
-				&err);
+    currentValue = gconf_client_get_string (client,
+					    METACITY
+					    "/general/mouse_button_modifier",
+					    &err);
     if (err)
     {
 	free (modifiers);
 	g_error_free (err);
-	return;
+	return FALSE;
     }
 
     if (!currentValue || (strcmp (currentValue, modifiers) != 0))
@@ -1426,6 +1439,8 @@ setGnomeMouseButtonModifier (unsigned int modMask)
 	g_free (currentValue);
 
     free (modifiers);
+
+    return TRUE;
 }
 
 static void
@@ -1598,13 +1613,16 @@ writeIntegratedOption (CCSContext *context,
 		unsigned int modMask;
 
 		modMask = setting->value->value.asButton.buttonModMask;
-		setGnomeMouseButtonModifier (modMask);
-		setButtonBindingForSetting (context, "move",
-					    "initiate_button", 1, modMask);
-		setButtonBindingForSetting (context, "resize",
-					    "initiate_button", 2, modMask);
-		setButtonBindingForSetting (context, "core",
-					    "window_menu_button", 3, modMask);
+		if (setGnomeMouseButtonModifier (modMask))
+		{
+		    setButtonBindingForSetting (context, "move",
+						"initiate_button", 1, modMask);
+		    setButtonBindingForSetting (context, "resize",
+						"initiate_button", 2, modMask);
+		    setButtonBindingForSetting (context, "core",
+						"window_menu_button",
+						3, modMask);
+		}
 	    }
 	}
      	break;
